@@ -3,7 +3,7 @@
  * $Id: cppvalue.cpp,v 1.6 2001/03/19 19:27:40 root Exp $
  *
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2010 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -71,7 +71,15 @@ CPPValue parseCharacter() // does not work for '\n' and the alike
       case '?':  return CPPValue((long)'\?');
       case '\'': return CPPValue((long)'\'');
       case '"':  return CPPValue((long)'"');
-      case '0':  return parseOctal();
+      case '0':  // fall through
+      case '1':  // fall through
+      case '2':  // fall through
+      case '3':  // fall through
+      case '4':  // fall through
+      case '5':  // fall through
+      case '6':  // fall through
+      case '7':  // fall through
+                 return parseOctal();
       case 'x': 
       case 'X':  return parseHexadecimal();
       default:   printf("Invalid escape sequence %s found!\n",g_strToken.data()); 
