@@ -2,7 +2,7 @@
  *
  * $Id: $
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2010 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -62,12 +62,12 @@ class DirDef : public Definition
     bool isCluster() const { return m_subdirs.count()>0; }
     int level() const { return m_level; }
     DirDef *parent() const { return m_parent; }
+    int dirCount() const { return m_dirCount; }
     const QDict<UsedDir> *usedDirs() const { return m_usedDirs; }
     bool isParentOf(DirDef *dir) const;
     bool depGraphIsTrivial() const;
 
     // generate output
-    void writeDetailedDocumentation(OutputList &ol);
     void writeDocumentation(OutputList &ol);
     void writeDepGraph(QTextStream &t);
 
@@ -76,6 +76,15 @@ class DirDef : public Definition
 
   private:
     friend void computeDirDependencies();
+
+    void writeDetailedDescription(OutputList &ol,const QCString &title);
+    void writeBriefDescription(OutputList &ol);
+    void writeDirectoryGraph(OutputList &ol);
+    void writeSubDirList(OutputList &ol);
+    void writeFileList(OutputList &ol);
+    void startMemberDeclarations(OutputList &ol);
+    void endMemberDeclarations(OutputList &ol);
+
     void setLevel();
     static DirDef *createNewDir(const char *path);
     static bool matchPath(const QCString &path,QStrList &l);
