@@ -31,7 +31,7 @@
 "	-webkit-column-count: 3;\n"
 "}\n"
 "\n"
-"p.startli, p.startdd {\n"
+"p.startli, p.startdd, p.starttd {\n"
 "	margin-top: 2px;\n"
 "}\n"
 "\n"
@@ -43,6 +43,10 @@
 "	margin-bottom: 4px;\n"
 "}\n"
 "\n"
+"p.endtd {\n"
+"	margin-bottom: 2px;\n"
+"}\n"
+"\n"
 "/* @end */\n"
 "\n"
 "caption {\n"
@@ -54,6 +58,11 @@
 "        text-align: center;\n"
 "}\n"
 "\n"
+"h3.version {\n"
+"        font-size: 90%;\n"
+"        text-align: center;\n"
+"}\n"
+"\n"
 "div.qindex, div.navtab{\n"
 "	background-color: #e8eef2;\n"
 "	border: 1px solid #84b0c7;\n"
@@ -110,9 +119,11 @@
 "}\n"
 "\n"
 "a.code {\n"
+"	color: #3030f0;\n"
 "}\n"
 "\n"
 "a.codeRef {\n"
+"	color: #3030f0;\n"
 "}\n"
 "\n"
 "/* @end */\n"
@@ -131,6 +142,10 @@
 "	background-color: #f5f5f5;\n"
 "	padding: 4px 6px;\n"
 "	margin: 4px 8px 4px 2px;\n"
+"	overflow: auto;\n"
+"	word-wrap: break-word;\n"
+"	font-size:  9pt;\n"
+"	line-height: 125%;\n"
 "}\n"
 "\n"
 "div.ah {\n"
@@ -288,11 +303,15 @@
 "}\n"
 "\n"
 "hr {\n"
-"	height: 0;\n"
+"	height: 0px;\n"
 "	border: none;\n"
 "	border-top: 1px solid #666;\n"
 "}\n"
 "\n"
+"hr.footer {\n"
+"	height: 1px;\n"
+"}\n"
+"\n"
 "/* @group Member Descriptions */\n"
 "\n"
 ".mdescLeft, .mdescRight,\n"
@@ -350,37 +369,46 @@
 "}\n"
 "\n"
 ".memname {\n"
-"	white-space: nowrap;\n"
-"	font-weight: bold;\n"
-"}\n"
-"\n"
-".memproto, .memdoc {\n"
-"	border: 1px solid #84b0c7;	\n"
+"        white-space: nowrap;\n"
+"        font-weight: bold;\n"
+"        margin-left: 6px;\n"
 "}\n"
 "\n"
 ".memproto {\n"
-"	padding: 0;\n"
-"	background-color: #d5e1e8;\n"
-"	font-weight: bold;\n"
-"	-webkit-border-top-left-radius: 8px;\n"
-"	-webkit-border-top-right-radius: 8px;\n"
-"        -webkit-box-shadow: 5px 5px 5px rgba(0, 0, 0, 0.15);\n"
-"	-moz-border-radius-topleft: 8px;\n"
-"	-moz-border-radius-topright: 8px;\n"
+"        border-top: 1px solid #84b0c7;          \n"
+"        border-left: 1px solid #84b0c7;         \n"
+"        border-right: 1px solid #84b0c7; \n"
+"        padding: 0;\n"
+"        background-color: #d5e1e8;\n"
+"        font-weight: bold;\n"
+"        /* firefox specific markup */\n"
+"        background-image: -moz-linear-gradient(rgba(228, 233, 245, 1.0) 0%, rgba(193, 205, 232, 1.0) 100%);\n"
 "        -moz-box-shadow: rgba(0, 0, 0, 0.15) 5px 5px 5px;\n"
+"        -moz-border-radius-topright: 8px;\n"
+"        -moz-border-radius-topleft: 8px;\n"
+"        /* webkit specific markup */\n"
+"        background-image: -webkit-gradient(linear, 0% 0%, 0% 100%, from(rgba(228, 233, 245, 1.0)), to(rgba(193, 205, 232, 1.0)));\n"
+"        -webkit-box-shadow: 5px 5px 5px rgba(0, 0, 0, 0.15);\n"
+"        -webkit-border-top-right-radius: 8px;\n"
+"        -webkit-border-top-left-radius: 8px;\n"
 "\n"
 "}\n"
 "\n"
 ".memdoc {\n"
-"	padding: 2px 5px;\n"
-"	background-color: #eef3f5;\n"
-"	border-top-width: 0;\n"
-"	-webkit-border-bottom-left-radius: 8px;\n"
-"	-webkit-border-bottom-right-radius: 8px;\n"
-"        -webkit-box-shadow: 5px 5px 5px rgba(0, 0, 0, 0.15);\n"
-"	-moz-border-radius-bottomleft: 8px;\n"
-"	-moz-border-radius-bottomright: 8px;\n"
+"        border-bottom: 1px solid #84b0c7;      \n"
+"        border-left: 1px solid #84b0c7;      \n"
+"        border-right: 1px solid #84b0c7; \n"
+"        padding: 2px 5px;\n"
+"        background-color: #eef3f5;\n"
+"        border-top-width: 0;\n"
+"        /* firefox specific markup */\n"
+"        -moz-border-radius-bottomleft: 8px;\n"
+"        -moz-border-radius-bottomright: 8px;\n"
 "        -moz-box-shadow: rgba(0, 0, 0, 0.15) 5px 5px 5px;\n"
+"        /* webkit specific markup */\n"
+"        -webkit-border-bottom-left-radius: 8px;\n"
+"        -webkit-border-bottom-right-radius: 8px;\n"
+"        -webkit-box-shadow: 5px 5px 5px rgba(0, 0, 0, 0.15);\n"
 "}\n"
 "\n"
 ".paramkey {\n"
@@ -496,3 +524,22 @@
 "	font-style: normal;\n"
 "	color: #333;\n"
 "}\n"
+"\n"
+"table.doxtable {\n"
+"	border-collapse:collapse;\n"
+"}\n"
+"\n"
+"table.doxtable td, table.doxtable th {\n"
+"	border: 1px solid #153788;\n"
+"	padding: 3px 7px 2px;\n"
+"}\n"
+"\n"
+"table.doxtable th {\n"
+"	background-color: #254798;\n"
+"	color: #FFFFFF;\n"
+"	font-size: 110%;\n"
+"	padding-bottom: 4px;\n"
+"	padding-top: 5px;\n"
+"	text-align:left;\n"
+"}\n"
+"\n"
