@@ -2,7 +2,7 @@
  *
  * $Id: vhdlscanner.h,v 1.9 2001/03/19 19:27:39 root Exp $
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2010 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -105,7 +105,7 @@ class VhdlDocGen
     static void debugClassName(ClassSDict*);
     //static void MergeFuncDoc(Entry* p,Entry* root);
 
-    static void computeVhdlComponentRelations(const QDict<EntryNav>&,FileStorage*);
+    static void computeVhdlComponentRelations();
 
     //static void  addVariableToComponents(EntryNav *rootNav,ClassDef *cd, MemberDef::MemberType mtype, const QCString &name, bool fromAnnScope,MemberDef *fromAnnMemb,Protection prot,bool related);
 
@@ -264,7 +264,7 @@ class VhdlDocGen
     static bool membersHaveSpecificType(MemberList *ml,int type);
     static void startFonts(const QCString& q, const char *keyword,OutputList& ol);
     static bool isNumber(const QCString& s);
-
+    static QCString getProtectionName(int prot);
   private:
     static void getFuncParams(QList<Argument>&, const char* str);
     static bool compareArgList(ArgumentList*,ArgumentList*);
